@@ -10,7 +10,8 @@ IRT.irfprob.tam <- function( object , ... ){
 	attr(ll,"G") <- 1
     return(ll)
         }
-IRT.irfprob.tam.mml <- IRT.irfprob.tam		
+IRT.irfprob.tam.mml <- IRT.irfprob.tam
+# IRT.irfprob.tam.mfr <- IRT.irfprob.tam		
 ###########################################################
 
 ###########################################################
@@ -27,3 +28,15 @@ IRT.irfprob.tam.mml.3pl <- function( object , ... ){
         }
 ###########################################################
 
+###########################################################
+# objects of class tamaan
+IRT.irfprob.tamaan <- function( object , ... ){
+	if (object$tamaanify$method %in% c( "tam.mml" , "tam.mml.2pl")  ){
+			res0 <- IRT.irfprob.tam( object , ... )			
+			}
+	if (object$tamaanify$method == "tam.mml.3pl"){
+			res0 <- IRT.irfprob.tam.mml.3pl( object , ... )			
+							}
+	return(res0)	
+			}
+###################################################################			
\ No newline at end of file
